@@ -4,7 +4,7 @@ use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new{
   my ($class) = @_;
@@ -21,13 +21,15 @@ sub find{
   my ($self,$text) = @_;
   my @array = ();
   $self->_Counter(0);
-  if(defined $text){
-    $text =~ s,<<'(.*?)'.*?\n\1,,sg;
-    $text =~ s,'.*?',,sg;
-    $text =~ s,q~.*?~,,sg;
-    @array = $text =~ m/(?:(\$\w+(?:->)?(?:\[\$?\w+\]|\{\$?\w+\}))|(\$\{\w+\})|(\$\w+))/sg;
-    @array = grep{defined}@array;
-  }
+
+  return if !defined $text;
+
+  $text =~ s,<<'(.*?)'.*?\n\1,,sg;
+  $text =~ s,'.*?',,sg;
+  $text =~ s,q~.*?~,,sg;
+  @array = $text =~ m/(?:(\$\w+(?:->)?(?:\[\$?\w+\]|\{\$?\w+\}))|(\$\{\w+\})|(\$\w+))/sg;
+  @array = grep{defined}@array;
+
   $self->_Elements(@array);
   return wantarray ? @{$self->_Elements()} : $self->_Elements();
 }# find
@@ -91,7 +93,7 @@ Text::Find::Scalar
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
